m4us.core.messages — Message For You Sir! v0.2.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Message For You Sir! v0.2.1 documentation »
- API Documentation »

# `m4us.core.messages`

Provides commonly used messages to be passed between coroutines.

## Inheritance Diagram

## Members

class `Message`(**kwargs)

  Bases: `object`

  Base class for special messages passed between coroutines.

  Implements : | `IMessage`
  Provides : | `IMessageFactory`

class `ProducerFinished`(**kwargs)

  Bases: `m4us.core.messages.Message`

  Message that indicates that a producer has finished.

  Implements : | `IProducerFinished`
  Provides : | `IMessageFactory`

class `Shutdown`(**kwargs)

  Bases: `m4us.core.messages.Message`

  Message that indicates that a coroutine should shutdown.

  Implements : | `IShutdown`
  Provides : | `IMessageFactory`

### Navigation

- index
- modules |
- next |
- previous |
- Message For You Sir! v0.2.1 documentation »
- API Documentation »